BarcodeScannerPocPlatform class abstract

The platform interface for the Barcode Scanner POC plugin.

Platform-specific implementations should extend this class.

Inheritance
  • Object
  • PlatformInterface
  • BarcodeScannerPocPlatform
Implementers

Constructors

BarcodeScannerPocPlatform()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPlatformVersion() Future<String?>
Returns the platform version as a String.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scanBarcode() Future<String?>
Scans a barcode and returns the result as a String.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance BarcodeScannerPocPlatform
The current instance of BarcodeScannerPocPlatform.
getter/setter pair