BarcodeScannerPoc class
Main entry point for the Barcode Scanner POC library.
Provides static methods to interact with the barcode scanner functionality.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
platformVersion
→ Future<
String?> -
Returns the platform version as a String.
no setter
Static Methods
-
scanBarcode(
) → Future< String?> - Scans a barcode and returns the result as a String.