BarcodeScannerPocWebOptions class
Options for configuring the web barcode scanner.
Constructors
Properties
-
extraOptions
→ Map<
String, dynamic> ? -
Additional custom options for html5-qrcode.
final
- focusMode → String?
-
Camera focus mode (if supported).
final
- fps → int
-
Frames per second for the scanner (default: 10).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int?
-
Preferred video height in pixels.
final
- qrbox → int
-
Size of the QR/barcode scanning box (default: 250).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → int?
-
Preferred video width in pixels.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toWebConfig(
) → Map< String, dynamic> - Converts the Dart options to a JS-friendly configuration map.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited